precision highp float;
varying highp vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform highp vec2 inputSize;
uniform highp float iTime;

uniform int level;
uniform highp float effectValue;

const float baseOffset = 10.0 / 1080.0;

vec3 rgb2hsv(vec3 color) {
    vec4 K = vec4(0.0, -1.0 / 3.0, 2.0 / 3.0, -1.0);
    vec4 p = mix(vec4(color.bg, K.wz), vec4(color.gb, K.xy), step(color.b, color.g));
    vec4 q = mix(vec4(p.xyw, color.r), vec4(color.r, p.yzx), step(p.x, color.r));

    float d = q.x - min(q.w, q.y);
    float e = 1.0e-10;
    return vec3(abs(q.z + (q.w - q.y) / (6.0 * d + e)), d / (q.x + e), q.x);
}

vec3 hsv2rgb(vec3 color) {
    vec4 K = vec4(1.0, 2.0 / 3.0, 1.0 / 3.0, 3.0);
    vec3 p = abs(fract(color.xxx + K.xyz) * 6.0 - K.www);
    return color.z * mix(K.xxx, clamp(p - K.xxx, 0.0, 1.0), color.y);
}

float lum(vec4 color) {
    return dot(color.rgb, vec3(0.299,0.587,0.114));
}

void main() {
    vec2 uv = textureCoordinate;
    vec2 offset = inputSize / 1080.0 * baseOffset * effectValue;
    vec4 originColor = texture2D(inputImageTexture, uv);
    vec2 offsetUv = uv - offset;
    vec4 offsetCol = texture2D(inputImageTexture, offsetUv);
    vec4 diffCol = originColor - offsetCol;
    float lumance = lum(diffCol);
    vec4 reliefCol = vec4(vec3(lumance), 0.0) + originColor;
    vec3 hsv = rgb2hsv(reliefCol.rgb);
    hsv.g *= 0.8;
    reliefCol.rgb = hsv2rgb(hsv);
    gl_FragColor = mix(originColor, reliefCol, 0.5);
}