precision highp float;
varying vec2 textureCoordinate;
uniform sampler2D inputImageTexture;
uniform float iTime;
uniform vec2 inputSize;

uniform int level;
uniform int isPhoto;
uniform float effectValue;

// 2D Random
float random (in vec2 st) {
    return fract(sin(dot(st.xy,
    vec2(12.9898,78.233)))
    * 43758.5453123);
}

// 2D Noise based on Morgan McGuire @morgan3d
// https://www.shadertoy.com/view/4dS3Wd
float noise (in vec2 st) {
    vec2 i = floor(st);
    vec2 f = fract(st);

    // Four corners in 2D of a tile
    float a = random(i);
    float b = random(i + vec2(1.0, 0.0));
    float c = random(i + vec2(0.0, 1.0));
    float d = random(i + vec2(1.0, 1.0));

    // Smooth Interpolation

    // Cubic Hermine Curve.  Same as SmoothStep()
    vec2 u = f*f*(3.0-2.0*f);
    // u = smoothstep(0.,1.,f);

    // Mix 4 coorners percentages
    float val =  mix(a, b, u.x) +
    (c - a)* u.y * (1.0 - u.x) +
    (d - b) * u.x * u.y;

    return fract(val);
}

void main() {
    vec2 uv = textureCoordinate;
    float dis = distance(uv, vec2(0.5, 0.5));
    float expoLevel = - smoothstep(0.5, 0.75, dis);
    vec4 resultCol = texture2D(inputImageTexture, uv);
    if(1.0 - uv.y < 0.8) {
        resultCol.rgb *= pow(2.0, expoLevel);
        gl_FragColor = resultCol;
        return;
    }
    float offset = noise(vec2(floor(uv.y * inputSize.y / 3.0), floor(iTime * 16.0))) * 0.04;
    uv.x += offset * abs(sin(iTime + uv.y * (60.0 * (1.0 + fract(iTime * 30.0)))) * cos(iTime + pow(uv.y, 2.0) * 50.0));
    if(uv.x < 0.0 || uv.x > 1.0) {
        resultCol = vec4(0.0);
    } else {
        resultCol = texture2D(inputImageTexture, uv);
    }
    resultCol.rgb *= pow(2.0, expoLevel);
    gl_FragColor = resultCol;
}